netapp_ontap.models.lun_map_igroup API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.lun_map_igroup`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class LunMapIgroupSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the LunMapIgroup object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `initiators GET`

    The initiators that are members of the initiator group.

  `links GET`

    The links field of the lun_map_igroup.

  `name GET POST`

    The name of the initiator group. Valid in POST.

    Example: igroup1

  `os_type GET`

    The host operating system of the initiator group. All initiators in the group should be hosts of the same operating system.

    Valid choices:

    - aix
    - hpux
    - hyper_v
    - linux
    - netware
    - openvms
    - solaris
    - vmware
    - windows
    - xen
  `protocol GET`

    The protocols supported by the initiator group. This restricts the type of initiators that can be added to the initiator group.

    Valid choices:

    - fcp
    - iscsi
    - mixed
  `uuid GET POST`

    The unique identifier of the initiator group. Valid in POST.

    Example: 1ad8544d-8cd1-91e0-9e1c-723478563412